Learn R Programming

BioInstaller (version 0.3.7)

BioInstaller: This package is a new platform to construct interactive and reproducible biological data analysis applications based on R language, which includes the R functions and R Shiny application, REST APIs.

Description

This package is a new platform to construct interactive and reproducible biological data analysis applications based on R language, which includes the R functions and R Shiny application, REST APIs.

Arguments

See Also

Useful links:

https://github.com/JhuangLab/BioInstaller

Report bugs at https://github.com/JhuangLab/BioInstaller/issues