This package is a new platform to construct interactive and reproducible biological data analysis applications based on R language, which includes the R functions and R Shiny application, REST APIs.
Useful links:
https://github.com/JhuangLab/BioInstaller
Report bugs at https://github.com/JhuangLab/BioInstaller/issues