Learn R Programming

BioInstaller (version 0.1.2)

BioInstaller: This package can be used to install and download massive bioinformatics analysis softwares and databases, such as NGS reads mapping tools with its required databases.

Description

This package can be used to install and download massive bioinformatics analysis softwares and databases, such as NGS reads mapping tools with its required databases.

Arguments

See Also

Useful links:

https://github.com/Miachol/BioInstaller

Report bugs at https://github.com/Miachol/BioInstaller/issues