This package can be used to install and download massive bioinformatics analysis softwares and databases, such as NGS reads mapping tools with its required databases.
Useful links:
https://github.com/Miachol/BioInstaller
Report bugs at https://github.com/Miachol/BioInstaller/issues